/*
 * (C) Dhananjay Nene - 2005
 * This source is licensed under Creative Commons License (Attribution 2.0)
 * (http://creativecommons.org/licenses/by/2.0/legalcode)
 */

package com.dnene.ditutorial.common;

import java.util.Date;

/**
 * An airline agency keeps track of various airline schedules and
 * performs activities necessary for ticket booking
 * 
 * @author Dhananjay Nene
 *
 */
public interface AirlineAgency
{
	/**
	 * Gets the airport from where a particular flight is scheduled
	 * to depart
	 * @param flightNumber
	 * @return airport code
	 */
	public String getDepartingAirport(String flightNumber);
	/**
	 * Gets the departure time for a particular flight
	 * @param flightNumber
	 * @return Departure time
	 */
	public Date getDepartureTime(String flightNumber);
	/**
	 * Books a ticket based on where a customer would choose to
	 * depart from, the destination and the preferred arrival time
	 * @param departingZipCode
	 * @param arrivalZipCode
	 * @param arrivalTime
	 * @return Flight schedule corresponding to the ticket booked for the customer
	 */
	public FlightSchedule bookTicket(String departingZipCode, String arrivalZipCode, Date arrivalTime);
}
