/*
 * (C) Dhananjay Nene, Pune, India - 2005
 * All Rights Reserved. 
 * To be used strictly pursuant to written license agreements.
 */
package com.dnene.ditutorial.common.impl;

import java.util.Date;

import com.dnene.ditutorial.common.AirlineAgency;
import com.dnene.ditutorial.common.CabAgency;
import com.dnene.ditutorial.common.FlightSchedule;
import com.dnene.ditutorial.common.TripPlanner;

/**
 * Provides basic functionality for trip planning. Is able to
 * coordinate between the cabAgency and the airline
 * agency. However this class does not have the elements necessary
 * to actually populate the references to the airline and cab
 * agencies
 * 
 * @author Dhananjay Nene
 *
 */
public abstract class AbstractTripPlanner implements TripPlanner
{
	/**
	 * Airline agency
	 */
	protected AirlineAgency airlineAgency = null;
	/**
	 * Cab agency
	 */
	protected CabAgency cabAgency = null;

	/** 
	 * Provides basic functionality related to planning a trip. Is able to
	 * coordinate between the airline and cab agencies and book tickets and
	 * schedule a cab pickup for the preferences as expressed in the arguments.
	 * 
	 * @see com.dnene.ditutorial.common.TripPlanner#planTrip(java.lang.String, java.lang.String, java.lang.String, java.util.Date)
	 */
	public void planTrip(String departingAddress, String departingZipCode, String arrivalZipCode, Date preferredArrivalTime)
	{
		FlightSchedule schedule = airlineAgency.bookTicket(departingZipCode,arrivalZipCode,preferredArrivalTime);		
		cabAgency.requestCab(departingAddress ,schedule.getFlightNumber());
	}

}
