/*
 * (C) Dhananjay Nene - 2005
 * This source is licensed under Creative Commons License (Attribution 2.0)
 * (http://creativecommons.org/licenses/by/2.0/legalcode)
 */

package com.dnene.ditutorial.common.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import com.dnene.ditutorial.common.AirlineAgency;
import com.dnene.ditutorial.common.FlightSchedule;

/**
 * A Simple AirlineAgencyImplementation
 * (Note : Has some hardcoded values for simplicity of
 * implementation)
 * 
 * @author Dhananjay Nene
 *
 */
public class SimpleAirlineAgency implements AirlineAgency
{
	private Map flights = new HashMap();
	
	/**
	 * Simple constructor which initialises the list of flights
	 */
	public SimpleAirlineAgency()
	{
		long now = System.currentTimeMillis();
		FlightSchedule schedule = new FlightSchedule("JFK",new Date(now + 43200000),new Date(now + 36000000),"DL123");
		flights.put("DL123",schedule);
	}
	
	/**
	 * Gets the departing airport for the given flightnumber
	 * @see com.dnene.ditutorial.common.AirlineAgency#getDepartingAirport(java.lang.String)
	 */
	public String getDepartingAirport(String flightNumber)
	{
		return "JFK";
	}

	/**
	 * Books tickets based on the arguments
	 * @see com.dnene.ditutorial.common.AirlineAgency#bookTicket(java.lang.String, java.lang.String, java.util.Date)
	 */
	public FlightSchedule bookTicket(
		String departingZipCode,
		String arrivalZipCode,
		Date arrivalTime)
	{
		FlightSchedule schedule = (FlightSchedule) flights.get("DL123");
		System.out.println("Flight confirmed :" + schedule);
		return schedule;
	}

	/**
	 * Gets departure time for a flight number
	 * @see com.dnene.ditutorial.common.AirlineAgency#getDepartureTime(java.lang.String)
	 */
	public Date getDepartureTime(String flightNumber)
	{
		FlightSchedule schedule = (FlightSchedule) flights.get(flightNumber);
		if (schedule != null)
		{
			return schedule.getDepartureTime();
		}
		return null;
	}
	
}
