/*
 * (C) Dhananjay Nene - 2005
 * This source is licensed under Creative Commons License (Attribution 2.0)
 * (http://creativecommons.org/licenses/by/2.0/legalcode)
 */

package com.dnene.ditutorial.hivemind;

import org.apache.hivemind.Registry;
import org.apache.hivemind.impl.RegistryBuilder;

import com.dnene.ditutorial.common.TripPlanner;
import com.dnene.ditutorial.harness.AbstractHarness;

/**
 * An implementation of the harness using Hivemind DI container
 * 
 * @author Dhananjay Nene
 *
 */
public class HivemindHarness extends AbstractHarness
{
	private Registry registry = null;
	private TripPlanner planner = null;
	
	public static void main(String[] args) throws Exception
	{
		new HivemindHarness().runHarness();
	}

	/** 
	 * Typical configuration activities require initialization of the registry
	 * 
	 * @see com.dnene.ditutorial.harness.Harness#configure()
	 */
	public void configure() throws Exception
	{
		registry = RegistryBuilder.constructDefaultRegistry();
	}

	/**
	 * Typically service location requires a lookup from the registry
	 * 
	 * @see com.dnene.ditutorial.harness.Harness#getPlanner()
	 */
	public TripPlanner getPlanner()
	{		
		return (TripPlanner) registry.getService(TripPlanner.class);
	}


}
