/*
 * (C) Dhananjay Nene - 2005
 * This source is licensed under Creative Commons License (Attribution 2.0)
 * (http://creativecommons.org/licenses/by/2.0/legalcode)
 */

package com.dnene.ditutorial.pico;

import org.picocontainer.MutablePicoContainer;
import org.picocontainer.defaults.DefaultPicoContainer;

import com.dnene.ditutorial.common.TripPlanner;
import com.dnene.ditutorial.common.impl.ConstructorBasedCabAgency;
import com.dnene.ditutorial.common.impl.ConstructorBasedTripPlanner;
import com.dnene.ditutorial.common.impl.SimpleAirlineAgency;
import com.dnene.ditutorial.harness.AbstractHarness;

/**
 * An implementation of the Execution Harness using PicoContainer
 * 
 * @author Dhananjay Nene
 *
 */
public class PicoHarness extends AbstractHarness
{
	private MutablePicoContainer pico = null;
	
	public static void main(String[] args) throws Exception
	{
		new PicoHarness().runHarness();
	}

	/**
	 * Typical configuration activities require registration fo the necessary classes
	 * 
	 * @see com.dnene.ditutorial.harness.Harness#configure()
	 */
	public void configure() throws Exception
	{
		
		pico = new DefaultPicoContainer();
		pico.registerComponentImplementation(SimpleAirlineAgency.class);
		pico.registerComponentImplementation(ConstructorBasedCabAgency.class);
		pico.registerComponentImplementation(ConstructorBasedTripPlanner.class);
	}

	/**
	 * Lookup requires a lookup from the container using the interface whose implementation
	 * is required.
	 * 
	 * @see com.dnene.ditutorial.harness.Harness#getPlanner()
	 */
	public TripPlanner getPlanner()
	{
		return (TripPlanner) pico.getComponentInstanceOfType(TripPlanner.class);
	}
}
