/*
 * (C) Dhananjay Nene - 2005
 * This source is licensed under Creative Commons License (Attribution 2.0)
 * (http://creativecommons.org/licenses/by/2.0/legalcode)
 */

package com.dnene.ditutorial.spring;

import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.xml.XmlBeanFactory;
import org.springframework.core.io.ClassPathResource;

import com.dnene.ditutorial.common.TripPlanner;
import com.dnene.ditutorial.harness.AbstractHarness;

/**
 * An implementation of the Execution Harness using Spring Framework
 * 
 * @author Dhananjay Nene
 *
 */
public class SpringHarness extends AbstractHarness
{
	private BeanFactory factory = null;
	
	public static void main(String[] args) throws Exception
	{
		new SpringHarness().runHarness();
	}

	/**
	 * Typical configuration activities require loading of an
	 * xml file and using that to configure a bean factory
	 * 
	 * @see com.dnene.ditutorial.harness.Harness#configure()
	 */
	public void configure() throws Exception
	{
		ClassPathResource res = new ClassPathResource("spring-beans.xml");
		factory = new XmlBeanFactory(res);
	}

	/**
	 * References to beans are easily resolved by requesting the
	 * factory
	 * 
	 * @see com.dnene.ditutorial.harness.Harness#getPlanner()
	 */
	public TripPlanner getPlanner() throws Exception
	{
		return (TripPlanner) factory.getBean("TripPlanner");
	}
}
