/*
 * (C) Dhananjay Nene - 2005
 * This source is licensed under Creative Commons License (Attribution 2.0)
 * (http://creativecommons.org/licenses/by/2.0/legalcode)
 */

package com.dnene.ditutorial.xwork;

import java.io.InputStream;

import com.dnene.ditutorial.common.TripPlanner;
import com.dnene.ditutorial.harness.AbstractHarness;
import com.dnene.ditutorial.harness.Harness;
import com.opensymphony.xwork.interceptor.component.ComponentConfiguration;
import com.opensymphony.xwork.interceptor.component.ComponentManager;
import com.opensymphony.xwork.interceptor.component.DefaultComponentManager;

/**
 * An implementation of the Execution Harness using xwork framework
 * 
 * @author Dhananjay Nene
 *
 */
public class XworkHarness extends AbstractHarness implements Harness
{
	private ComponentManager cm = null;
	private TripPlanner planner = null;
	
	public static void main(String[] args) throws Exception
	{
		new XworkHarness().runHarness();
	}
	
	/**
	 * Configuration requires reading in data from an xml file and using
	 * that to configure the component manager.
	 * 
	 * @see com.dnene.ditutorial.xwork.SampleExecution#configure()
	 */
	public void configure() throws Exception
	{
		ComponentConfiguration config = new ComponentConfiguration();
		InputStream in = XworkHarness.class.getClassLoader().getResourceAsStream("components.xml");
		config.loadFromXml(in);
		cm = new DefaultComponentManager();
		config.configure(cm,"application");		
	}
	
	/**
	 * Lookups involve a simple lookup on the component manager.
	 * 
	 * @see com.dnene.ditutorial.xwork.SampleExecution#getPlanner()
	 */
	public TripPlanner getPlanner()
	{
		return (TripPlanner) cm.getComponent(TripPlannerAware.class);
	}
}
